Class: Page
Overview
This class is used for getting the pages from the wordpress database
Examples:
User.find(1).pages
The above will find the user with id of 1 and retrieve all of the pages they have ever made Page.find(1) The above will find the pge with id of 1
Inherited methods
[find id] Retrieves the page with the sepcified id [all] Retrieves all of the pages in the database [title] The title of the page [title= title] Set the title of the page [content] The content of the page [content=] Set the content of the page
Database Keys
[ID alias: id] The pages` id [post_author alias: user.id] The User id of who created the Page Page.find(1).user The above returns the User that the page belongs to [post_date] The date the page was created [post_date_gmt] The date the page was created in gmt/utc time [post_content alias: PagePost#content] The content of the page [post_title alias: PagePost#title] The title of the page [post_excerpt] The excerpt of the page [post_status] The status of the page e.g. +Published+ [comment_status] Whether or not comments are allowed e.g. open [ping_status] Whether or not pings are allowed e.g. open [post_password] The password (if any) required to view the page [post_name] The url version of the page e.g. example-page [to_ping] Unknown [pinged] Unknown [post_modified] The date the page last edited [post_modified_gmt] The date the page last edited in gmt/utc time [post_content_filtered] Unknown [post_parent] The pages parent id (if any) [guid] The full url to the page [menu_order] The order at which the page sits in the menu [post_type] The type of the post e.g. page or post (will always be page) [post_mime_type] The mime type of the post [comment_count] The amount of comments on the page [type] Used and created by wpb for activerecord inheritance